.. aaa documentation master file, created by
   sphinx-quickstart on Wed Oct 16 09:49:09 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.

Welcome to aaa's documentation!
===============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
